package fr.aminelouveaau.cartes;

import fr.aminelouveaau.cartes.model.Card;
import fr.aminelouveaau.cartes.service.GameService;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.test.util.ReflectionTestUtils;

import java.util.List;

import static org.assertj.core.api.AssertionsForClassTypes.assertThat;

@SpringBootTest
class CartesApplicationTests {

    public static final int CARDS_PER_HAND = 10;
    @InjectMocks
    GameService gameService;

    @BeforeEach
    public void setUp() {
        ReflectionTestUtils.setField(gameService, "cardHandNumber", CARDS_PER_HAND);
        gameService.init();
    }

    @Test
    void testDeckGeneration() {
        List<Card> deck = gameService.getDeck();
        assertThat(deck.size()).isNotEqualTo(0).withFailMessage("Deck is empty");
        assertThat(deck.size()).isEqualTo(4 * 13).withFailMessage("Deck is not complete");
    }

    @Test
    void testHandGeneration() {
        List<Card> hand = gameService.cardHand();
        assertThat(hand.size()).isEqualTo(CARDS_PER_HAND).withFailMessage("Hand is not complete");
        List<Card> deck = gameService.getDeck();
        assertThat(deck.size()).isNotEqualTo(4 * 13).withFailMessage("Where did the cards come from ?");
        assertThat(deck.size()).isEqualTo((4 * 13) - CARDS_PER_HAND).withFailMessage("Wrong number of cards removed.");
    }

    @Test
    void contextLoads() {
    }

}
